<?php
# Name: ebl_quill_editor
# Type: admin
# Author: Your Name
# Version: 0.2
# Description: Replaces Textpattern’s Body & Excerpt textareas with Quill rich text editor.
# Help:
# This plugin uses Quill to replace the Body and Excerpt fields on the Write panel.
# Quill offers a flexible, modern, and lightweight editing experience.


# --- Plugin code start ---

function ebl_quill_add_js($event, $step)
{
    // Only run on the Write panel
    if (gps('event') !== 'article') {
        return;
    }

    // Include Quill assets and initialize the editor
    echo <<<EOD
<style>
  /* Import Snow theme styling */
  @import url('https://cdn.jsdelivr.net/npm/quill@2.0.3/dist/quill.snow.css');

.ql-toolbar.ql-snow { margin-top: 5px; }

/* Snow toolbar styles */
.ql-toolbar {
  border: 1px solid #ccc !important;
  border-radius: 4px 4px 0 0 !important;
  background-color: #f9f9f9 !important; /* Light gray background */
  padding: 5px !important;
}

/* Style toolbar buttons */
.ql-toolbar .ql-picker,
.ql-toolbar button {
  color: #333 !important; /* Default button color */
  background-color: transparent !important;
  border: none !important;
}

.ql-toolbar button:hover,
.ql-toolbar .ql-picker:hover {
  color: #000 !important; /* Darker text on hover */
  background-color: #e6e6e6 !important; /* Light hover effect */
}

/* Style active buttons */
.ql-toolbar .ql-active {
  background-color: #ddd !important; /* Highlight active buttons */
}

/* Ensure the editor area has proper height, background, and text styling */
.ql-container {
  border: 1px solid #ccc !important; /* Match Snow theme toolbar border */
  background-color: #ffffff !important; /* Ensure a white background */
  min-height: 200px !important; /* Default editor height */
  color: #000000 !important; /* Default text color */
}

.ql-editor {
  background-color: #ffffff !important; /* White background for editing */
  color: #000000 !important; /* Black text color */
  min-height: 150px !important; /* Minimum height for content */
  padding: 10px !important; /* Space inside the editor */
  font-family: Arial, sans-serif !important; /* Consistent font */
  font-size: 14px !important; /* Base font size */
  line-height: 1.6 !important; /* Readable line spacing */
}

/* Prevent the editor from collapsing when empty */
.ql-editor:empty::before {
  content: attr(data-placeholder); /* Display placeholder text */
  color: #aaa !important; /* Placeholder color */
  font-style: italic;
}

</style>

<!-- Quill JS -->

<script src="https://cdn.jsdelivr.net/npm/quill@2.0.3/dist/quill.min.js"></script>

<script>
jQuery(function($) {
  // Remove dropdown.
  $('.txp-textarea-options.txp-textfilter-options.no-ui-button').find('label:has(select)').remove();

  // Initialize Quill for Body
  var \$body = $('#body');
  if (\$body.length) {
    // Create a div to replace the textarea
   \$body.hide(); // Hide the original textarea
    \$body.after('<div id="quill-body-editor" class="quill-editor-container"></div>');

    // Initialize Quill
    var quillBody = new Quill('#quill-body-editor', {
      theme: 'snow',
      placeholder: 'Write something amazing here...',
      modules: {
        toolbar: [
          [{ 'font': [] }],
          [{ header: [1, 2, 3, 4, 5, 6, false] }], // Headings
          [{ 'align': [] }],
          ['bold', 'italic', 'underline', 'strike'], // Formatting buttons
          [{ color: [] }, { background: [] }], // Color options
          ['blockquote', 'code-block'], // Block options
          [{ list: 'ordered' }, { list: 'bullet' }], // Lists
          [{ 'script': 'sub' }, { 'script': 'super' }], // Superscript/Subscript
          [{ 'indent': '-1' }, { 'indent': '+1' }], // Outdent/Indent
          ['link', 'image', 'video'], // Media options
          ['clean'] // Remove formatting
        ]
      }
    });

    // Sync Quill content back to the hidden textarea, preserving shortcodes
    quillBody.on('text-change', function() {
      var htmlContent = quillBody.root.innerHTML;

      // Convert encoded <txp::...> back to raw shortcodes
      htmlContent = htmlContent.replace(/&lt;(txp::[a-zA-Z0-9_:]+)([^>]*)&gt;/g, '<$1$2>');

      // Update the textarea
      \$body.val(htmlContent);
    });

    // Load initial content from the textarea, encoding shortcodes for Quill rendering
    var initialContent = \$body.val();
    initialContent = initialContent.replace(/<(txp::[a-zA-Z0-9_:]+)([^>]*)>/g, '&lt;$1$2&gt;');
    quillBody.root.innerHTML = initialContent;
  }

  // Initialize Quill for Excerpt
  var \$excerpt = $('#excerpt');
  if (\$excerpt.length) {
    // Create a div to replace the textarea
    \$excerpt.hide(); // Hide the original textarea
    \$excerpt.after('<div id="quill-excerpt-editor" class="quill-editor-container"></div>');

    // Initialize Quill
    var quillExcerpt = new Quill('#quill-excerpt-editor', {
      theme: 'snow',
      placeholder: 'Excerpt text here...',
      modules: {
        toolbar: [
          [{ header: [1, 2, 3, false] }], // Limited headings for excerpt
          ['bold', 'italic', 'underline'], // Basic formatting
          ['blockquote'], // Block options
          [{ list: 'ordered' }, { list: 'bullet' }], // Lists
          ['clean'] // Remove formatting
        ]
      }
    });

    // Sync Quill content back to the hidden textarea, preserving shortcodes
    quillExcerpt.on('text-change', function() {
      var htmlContent = quillExcerpt.root.innerHTML;

      // Convert encoded <txp::...> back to raw shortcodes
      htmlContent = htmlContent.replace(/&lt;(txp::[a-zA-Z0-9_:]+)([^>]*)&gt;/g, '<$1$2>');

      // Update the textarea
      \$excerpt.val(htmlContent);
    });

    // Load initial content from the textarea, encoding shortcodes for Quill rendering
    var initialContent = \$excerpt.val();
    initialContent = initialContent.replace(/<(txp::[a-zA-Z0-9_:]+)([^>]*)>/g, '&lt;$1$2&gt;');
    quillExcerpt.root.innerHTML = initialContent;
  }
});
</script>

EOD;
}

// Register callback to insert the script at admin-side head_end
if (@txpinterface == 'admin') {
    register_callback('ebl_quill_add_js', 'admin_side', 'head_end');
}
